start_unwind

Function start_unwind 

pub fn start_unwind(target: u64) -> Option<Receiver<Result<(), String>>>
Send an unwind request to the background persistence thread and return a receiver for the result. Blocks from target + 1 onward (and their execution state + trie state) are removed from disk. This runs on the same thread as flushes to avoid races with in-flight persistence.